const Mesa = require('vendor/Mesa.js');

/**
 * A Mesa Script exports a class with a script() method.
 */
module.exports = new class {

  /**
   * Mesa Script
   *
   * @param {object} payload The payload data
   * @param {object} context Additional context about this task
   */
  script = (payload, context) => {
    const vars = context.steps;

    let credential = JSON.parse(Mesa.credential.get('recharge_1'));
    let options = {
      "headers": {
        "Content-Type": "application/json",
        "X-Recharge-Access-Token": credential.access_token,
        "X-Recharge-Version": "2021-11"
      }
    }

    let today = new Date().toISOString().slice(0, 10);
    let productId = vars.shopify_1.id;
    let variantId = vars.shopify_1.variants[0].id;

    let data = {
        "address_id": vars.recharge.address_id,
        "external_product_id": {
          "ecommerce": productId.toString(),
        },
        "price": parseFloat(vars.custom_1.amount),
        "next_charge_scheduled_at": today,
        "product_title": "One off charge",
        "quantity": 1,
        "external_variant_id": {
            "ecommerce": variantId.toString(),
        }
    };

    let url = 'https://api.rechargeapps.com/onetimes';
    let response = Mesa.request.post(url, data, options);    

    if (response.errors) {
      throw new Error(JSON.stringify(response.errors));
    }

    Mesa.trigger.setTaskExternalData({
      "label": "Created onetime #" + response.onetime.id,
    })

    Mesa.output.next(payload);
  }
}
